@@ -13,7 +13,7 @@ require 5.002;
 package MLDBM;
 use strict;
 
-$MLDBM::VERSION = $MLDBM::VERSION = '1.23';
+$MLDBM::VERSION = $MLDBM::VERSION = '1.24';
 
 require Tie::Hash;
 @MLDBM::ISA = qw(Tie::Hash);
@@ -72,7 +72,7 @@ sub FETCH {
     return($M ? $M : $N) unless $@;
     carp "MLDBM error: $@\twhile evaluating:\n $ret";
   }
-  return undef;
+  return $ret;
 }
 
 sub STORE {
@@ -280,7 +280,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.23    26 August 1996
+Version 1.24    29 October 1997
 
 =head1 SEE ALSO
 
